@@ -8,7 +8,6 @@ from typing import TYPE_CHECKING, Any
 
 import cirq
 import numpy as np
-import numpy.typing as npt
 from cirq.ops.common_gates import _pi
 
 import cirq_superstaq as css
@@ -16,6 +15,8 @@ import cirq_superstaq as css
 if TYPE_CHECKING:
     from types import NotImplementedType
 
+    import numpy.typing as npt
+
 
 def approx_eq_mod(a: cirq.TParamVal, b: cirq.TParamVal, period: float, atol: float = 1e-8) -> bool:
     """Check if a ~= b (mod period). If either input is an unresolved parameter, returns a == b.
@@ -478,7 +479,7 @@ class ParallelGates(cirq.Gate, cirq.InterchangeableQubitsGate):
             component_gates: Gate(s) to be collected into a single gate.
 
         Raises:
-            ValueError: If `component_gates` are not `cirq.Gate` instances.
+            TypeError: If `component_gates` are not `cirq.Gate` instances.
             ValueError: If `component_gates` contains measurements.
         """
         self.component_gates: tuple[cirq.Gate, ...] = ()
@@ -486,9 +487,9 @@ class ParallelGates(cirq.Gate, cirq.InterchangeableQubitsGate):
         # unroll any ParallelGate(s) instances in component_gates
         for gate in component_gates:
             if not isinstance(gate, cirq.Gate):
-                raise ValueError(f"{gate} is not a cirq Gate")
+                raise TypeError(f"{gate} is not a `cirq.Gate`")
             elif cirq.is_measurement(gate):
-                raise ValueError("ParallelGates cannot contain measurements")
+                raise ValueError("`ParallelGates` cannot contain measurements")
             elif isinstance(gate, ParallelGates):
                 self.component_gates += gate.component_gates
             elif isinstance(gate, cirq.ParallelGate):
@@ -976,6 +977,9 @@ class StrippedCZGate(cirq.Gate):
             cirq.resolve_parameters(self.rz_rads, resolver, recursive),
         )
 
+    def _phase_by_(self, phase_turns: cirq.TParamVal, qubit_index: int) -> StrippedCZGate:
+        return self
+
     def _is_parameterized_(self) -> bool:
         return cirq.is_parameterized(self.rz_rads)
 
