@@ -22,7 +22,12 @@ def test_zz_swap_gate() -> None:
     cirq.testing.assert_equivalent_repr(gate, setup_code="import cirq_superstaq as css")
 
     expected = np.array(
-        [[1, 0, 0, 0], [0, 0, np.exp(1j * theta), 0], [0, np.exp(1j * theta), 0, 0], [0, 0, 0, 1]]
+        [
+            [1, 0, 0, 0],
+            [0, 0, np.exp(1j * theta), 0],
+            [0, np.exp(1j * theta), 0, 0],
+            [0, 0, 0, 1],
+        ]
     )
     assert np.allclose(cirq.unitary(gate), expected)
 
@@ -55,7 +60,7 @@ def test_zz_swap_gate() -> None:
 
     assert gate.__pow__(sympy.var("exponent")) is NotImplemented
 
-    with pytest.raises(TypeError, match="unsupported operand type"):
+    with pytest.raises(TypeError, match=r"unsupported operand type"):
         _ = gate**1.23
 
 
@@ -101,10 +106,10 @@ def test_zz_swap_parameterized() -> None:
     assert cirq.approx_eq(gate, css.ZZSwapGate(sympy.var("θ")))
     assert cirq.equal_up_to_global_phase(gate, css.ZZSwapGate(sympy.var("θ")))
 
-    with pytest.raises(TypeError, match="cirq.unitary failed. Value doesn't have"):
+    with pytest.raises(TypeError, match=r"cirq.unitary failed. Value doesn't have"):
         _ = cirq.unitary(gate)
 
-    with pytest.raises(TypeError, match="No Pauli expansion"):
+    with pytest.raises(TypeError, match=r"No Pauli expansion"):
         _ = cirq.pauli_expansion(gate)
 
 
@@ -117,7 +122,12 @@ def test_stripped_cz_gate() -> None:
     assert repr(gate) == "css.StrippedCZGate(0.123)"
     cirq.testing.assert_equivalent_repr(gate, setup_code="import cirq_superstaq as css")
     expected = np.diag(
-        [1.0, np.exp(1j * rz_rads), np.exp(1j * rz_rads), np.exp(1j * (2 * rz_rads - np.pi))]
+        [
+            1.0,
+            np.exp(1j * rz_rads),
+            np.exp(1j * rz_rads),
+            np.exp(1j * (2 * rz_rads - np.pi)),
+        ]
     )
     assert np.allclose(cirq.unitary(gate), expected)
 
@@ -151,6 +161,9 @@ def test_stripped_cz_gate() -> None:
     assert gate**1 == gate
     assert gate**2 == css.ParallelGates(z_exp_gate, z_exp_gate)
 
+    assert cirq.phase_by(gate, 1.23, 0) == gate
+    assert cirq.phase_by(operation, 1.23, 1) == operation
+
 
 def test_stripped_cz_gate_circuit() -> None:
     qubits = cirq.LineQubit.range(3)
@@ -176,9 +189,9 @@ def test_stripped_cz_gate_parameterized() -> None:
     assert cirq.approx_eq(gate, css.StrippedCZGate(sympy.var("φ")))
     assert cirq.equal_up_to_global_phase(gate, css.StrippedCZGate(sympy.var("φ")))
 
-    with pytest.raises(TypeError, match="cirq.unitary failed. Value doesn't have"):
+    with pytest.raises(TypeError, match=r"cirq.unitary failed. Value doesn't have"):
         _ = cirq.unitary(gate)
-    with pytest.raises(TypeError, match="No Pauli expansion"):
+    with pytest.raises(TypeError, match=r"No Pauli expansion"):
         _ = cirq.pauli_expansion(gate)
 
 
@@ -257,7 +270,7 @@ def test_zx_circuit() -> None:
 def test_acecr_init() -> None:
     css.AceCR("+-")
     css.AceCR("-+", sandwich_rx_rads=np.pi / 3)
-    with pytest.raises(ValueError, match="Polarity must be"):
+    with pytest.raises(ValueError, match=r"Polarity must be"):
         css.AceCR("++")
 
     css.AceCR(rads=np.pi / 3)
@@ -367,8 +380,8 @@ def test_acecr_eq() -> None:
     assert css.AceCR("+-", sandwich_rx_rads=np.pi) == css.AceCR("+-", sandwich_rx_rads=5 * np.pi)
 
     assert css.AceCR(rads=np.pi) == css.AceCR(rads=np.pi)
-    assert not css.AceCR(rads=-np.pi) == css.AceCR(rads=np.pi)
-    assert not css.AceCR(rads=np.pi) == css.AceCR(rads=3 * np.pi)
+    assert css.AceCR(rads=-np.pi) != css.AceCR(rads=np.pi)
+    assert css.AceCR(rads=np.pi) != css.AceCR(rads=3 * np.pi)
     assert css.AceCR(rads=np.pi) == css.AceCR(rads=5 * np.pi)
     assert css.AceCR(rads=np.pi, sandwich_rx_rads=np.pi) == css.AceCR(
         rads=np.pi, sandwich_rx_rads=np.pi
@@ -726,10 +739,10 @@ def test_parallel_gates() -> None:
         cirq.X, cirq.ParallelGate(cirq.Y, num_copies=2)
     )
 
-    with pytest.raises(ValueError, match="ParallelGates cannot contain measurements"):
+    with pytest.raises(ValueError, match=r"`ParallelGates` cannot contain measurements"):
         _ = css.ParallelGates(cirq.X, cirq.MeasurementGate(1, key="1"))
 
-    with pytest.raises(ValueError, match="is not a cirq Gate"):
+    with pytest.raises(TypeError, match=r"is not a `cirq.Gate`"):
         _ = css.ParallelGates(cirq.X(qubits[1]))
 
 
@@ -738,13 +751,15 @@ def test_parallel_gates_operation() -> None:
     op = css.parallel_gates_operation(cirq.CX(q2, q0), cirq.Y(q3))
     assert op == css.ParallelGates(cirq.CX, cirq.Y).on(q2, q0, q3)
 
-    with pytest.raises(ValueError, match="no .gate attribute"):
+    with pytest.raises(ValueError, match=r"no .gate attribute"):
         _ = css.parallel_gates_operation(cirq.X(q0).with_classical_controls("1"))
 
-    with pytest.raises(ValueError, match="tagged operations not permitted"):
+    with pytest.raises(ValueError, match=r"tagged operations not permitted"):
         _ = css.parallel_gates_operation(cirq.X(q0).with_tags("foo"))
 
-    with pytest.raises(ValueError):  # Overlapping qubits should be caught by cirq
+    with pytest.raises(
+        ValueError, match=r"Duplicate qids for"
+    ):  # Overlapping qubits should be caught by `cirq`
         _ = css.parallel_gates_operation(cirq.CX(q2, q0), cirq.Y(q2))
 
 
@@ -849,10 +864,10 @@ def test_parallel_gates_equivalence_groups() -> None:
             assert not cirq.approx_eq(operation, gate(*permuted_qubits))
             assert not cirq.equal_up_to_global_phase(operation, gate(*permuted_qubits))
 
-    with pytest.raises(ValueError, match="index out of range"):
+    with pytest.raises(ValueError, match=r"index out of range"):
         _ = gate.qubit_index_to_equivalence_group_key(4)
 
-    with pytest.raises(ValueError, match="index out of range"):
+    with pytest.raises(ValueError, match=r"index out of range"):
         _ = gate.qubit_index_to_equivalence_group_key(-1)
 
 
