@@ -85,7 +85,7 @@ def test_qudit_swap_op() -> None:
 
     assert css.qudit_swap_op(qubit0, qubit1) == cirq.SWAP(qubit0, qubit1)
     assert css.qudit_swap_op(qudit0, qudit1) == css.QuditSwapGate(7).on(qudit0, qudit1)
-    with pytest.raises(ValueError, match="do not have the same dimension"):
+    with pytest.raises(ValueError, match=r"do not have the same dimension"):
         _ = css.qudit_swap_op(qubit0, qudit1)
 
 
@@ -368,13 +368,13 @@ def test_virtual_z_pow_gate() -> None:
         use_unicode_characters=False,
     )
 
-    with pytest.raises(ValueError, match="Invalid dimension"):
+    with pytest.raises(ValueError, match=r"Invalid dimension"):
         _ = css.VirtualZPowGate(dimension=1)
 
-    with pytest.raises(ValueError, match="Invalid energy level"):
+    with pytest.raises(ValueError, match=r"Invalid energy level"):
         _ = css.VirtualZPowGate(dimension=3, level=3)
 
-    with pytest.raises(ValueError, match="Invalid energy level"):
+    with pytest.raises(ValueError, match=r"Invalid energy level"):
         _ = css.VirtualZPowGate(dimension=3, level=0)
 
 
@@ -434,16 +434,16 @@ def test_qubit_subspace_gate() -> None:
     assert css.QubitSubspaceGate(cirq.X, (3,), [(0, 2)]) == css.QubitSubspaceGate(
         cirq.X, (3,), [(0, -1)]
     )
-    with pytest.raises(ValueError, match="Only qubit gates"):
+    with pytest.raises(ValueError, match=r"Only qubit gates"):
         _ = css.QubitSubspaceGate(cirq.ZPowGate(dimension=3), (3,))
 
-    with pytest.raises(ValueError, match="same number of qubits"):
+    with pytest.raises(ValueError, match=r"same number of qubits"):
         _ = css.QubitSubspaceGate(cirq.Z, (3, 3))
 
-    with pytest.raises(ValueError, match="Invalid qid_shape"):
+    with pytest.raises(ValueError, match=r"Invalid qid_shape"):
         _ = css.QubitSubspaceGate(cirq.CZ, (1, 2))
 
-    with pytest.raises(ValueError, match="two subspace indices for every qubit"):
+    with pytest.raises(ValueError, match=r"two subspace indices for every qubit"):
         _ = css.QubitSubspaceGate(cirq.CZ, (3, 3), [(0, 1)])
 
     gate = css.QubitSubspaceGate(cirq.X, (3,))
@@ -459,7 +459,7 @@ def test_qubit_subspace_gate() -> None:
 
 
 @pytest.mark.parametrize(
-    "sub_gate_type, qid_shape, subspaces",
+    ("sub_gate_type", "qid_shape", "subspaces"),
     [
         (cirq.XPowGate, (3,), None),
         (cirq.YPowGate, (3,), [(1, 2)]),
@@ -585,5 +585,5 @@ def test_qubit_subspace_op() -> None:
     assert css.qubit_subspace_op(
         cirq.X(cirq.NamedQubit("qubit")), (4,), [(1, -1)]
     ) == css.QubitSubspaceGate(cirq.X, (4,), [(1, 3)]).on(cirq.NamedQid("qubit", dimension=4))
-    with pytest.raises(ValueError, match="has no gate."):
+    with pytest.raises(ValueError, match=r"has no gate."):
         _ = css.qubit_subspace_op(cirq.CircuitOperation(cirq.FrozenCircuit()), ())
